@@ -3,7 +3,8 @@
  *                                                                    
  * Xnee enables recording and replaying of X protocol data           
  *                                                                   
- *        Copyright (C) 1999, 2000, 2001, 2002, 2003 Henrik Sandklef                    
+ *      Copyright (C) 1999, 2000, 2001, 2002, 2003, 
+ *                    2009 Henrik Sandklef                    
  *                                                                   
  * This program is free software; you can redistribute it and/or     
  * modify it under the terms of the GNU General Public License       
@@ -609,6 +610,11 @@ typedef struct
 
   retype_settings  retype;
 
+  unsigned char   x_version_major;
+  unsigned char   x_version_minor;
+  unsigned char   x_version_minor_sub;
+  char *          x_vendor_name  ;
+
 } xnee_data ; 
 
 
